@@ -6,6 +6,7 @@ import random
 
 global img
 global point1, point2
+
 def screen_shot(device_type,devices):
     if device_type == 'android':
         if devices is None:
@@ -59,9 +60,5 @@ def get_iamge():
     crop()
 
 def element_click(element_keywords_name):
-    a='self.driver.'
-    b='(value).click()'
-    c=a+element_keywords_name+b
-    eval(c)
-
+    u2.connect_usb().xpath(element_keywords_name).click()
 
